/* profile.h
 *
 * Copyright (C) 2017 Timothy Richard Musson
 *
 * Email: Tim Musson <trmusson@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */


#ifndef HAVE_PROFILE_H
#define HAVE_PROFILE_H

#include "xlib/xlist.h"
#include "memory.h"


typedef enum {

	ENVIRONMENT_STDIO   =  0,
	ENVIRONMENT_NCURSES =  1,
	ENVIRONMENT_SDL     =  2

} Environment;


typedef struct {

	const char *progname;
	char       *dirname;
	char       *basename;
	char       *simulation_name;

	int         cpu_type;
	int         ram_base;
	int         ram_size;
	xbool_t     ram_clear;
	int         environment;
	int         video_type;
	int         video_base;
	int         video_size;
	char       *video_charset_fname;
	int         video_char_width;
	int         video_char_height;
	int         video_char_count;
	int         video_scale_w;
	int         video_scale_h;
	Byte        video_fg[3];
	Byte        video_bg[3];
	int         reset_timeout;
	int         screen_width;
	int         screen_height;
	int         keyboard_type;
	int         keyboard_base;
	int         acia;
	int         getc;
	int         putc;
	int         random;
	int         vector_nmi;
	int         vector_reset;
	int         vector_irq;
	int         startup;
	xlist_t     *rom_list;
	xlist_t     *load_list;

} Profile;


Profile* profile_new (const char *progname, const char *fname);
void     profile_free (Profile *p);


#endif

