/* xfile.h
 *
 * Copyright (C) 2005, 2020 Timothy Richard Musson
 *
 * Email: Tim Musson <trmusson@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */


#ifndef XFILE_H
#define XFILE_H


#ifdef _WIN32
#define DIR_SEPARATOR_S         "\\"
#define DIR_SEPARATOR_C         '\\'
#else
#define DIR_SEPARATOR_S         "/"
#define DIR_SEPARATOR_C         '/'
#endif
#define IS_DIR_SEPARATOR_C(c)   ((c) == DIR_SEPARATOR_C)

typedef enum {
	XFILE_TEST_EXISTS     = 1 << 0,
	XFILE_TEST_IS_REGULAR = 1 << 1,
	XFILE_TEST_IS_DIR     = 1 << 2
} XFileTest;


xbool_t xfile_test (const char *fname, XFileTest test);
char*   xfile_expand_tilde (const char *fname);
char*   xfile_dirname (const char *path);
char*   xfile_basename (const char *path);
char*   xfile_get_contents (FILE *f, size_t *len);
char*   xfile_get_contents_with_filename (const char *fname, size_t *len);

char*   xfile_get_cwd (void);


#ifndef __USE_GNU

#define GETLINE_GROW_SIZE       1024

ssize_t xfile_getdelim (char **lineptr, size_t *size, int delim, FILE *stream);
ssize_t xfile_getline (char **lineptr, size_t *size, FILE *stream);

#else

#define xfile_getdelim   getdelim
#define xfile_getline    getline

#endif /* ifndef __USE_GNU */


#endif /* XFILE_H */

